<?php
/*
Plugin Name: Country State City Dropdown PRO
Description: Add country, state and city dynamic drop down for any type of form. States will auto populate in dropdown according to selected country and cities will auto populate according to selected state.
Version: 5.7
Author: Trusty Plugins
Author URI: https://trustyplugins.com
Domain Path: /languages
Text Domain: tc_pro_csca
 */
// Block direct access to the main plugin file.
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}
class TC_PRO_CSCA_Plugin
{
    public function __construct()
    {
        add_action('plugins_loaded', array($this, 'tc_pro_load_plugin_data'));
    }

    public function tc_pro_load_plugin_data()
    {
        load_plugin_textdomain('tc_pro_csca', false, basename(dirname(__FILE__)) . '/languages/');
        if (!class_exists('TC_CSCA_Plugin')) {
            $this->tc_pro_plugin_constants();
            require_once TC_PRO_CSCA_PATH . 'includes/autoload.php';
            $serializer = new CSCA_Serializer();
            $serializer->init();
            $plugin = new CSCA_Submenu(new CSCA_Submenu_Page());
            $plugin->init();
            if (!class_exists('ReduxFramework') && file_exists(plugin_dir_path(__FILE__) . 'includes/options/framework.php')) {
                require_once 'includes/options/framework.php';
            }
            if (!isset($redux_demo) && file_exists(plugin_dir_path(__FILE__) . 'includes/options/config.php')) {
                require_once 'includes/options/config.php';
            }
        }
        add_action('admin_enqueue_scripts', array($this, 'load_custom_wp_admin_style'));

        if (class_exists('TC_CSCA_Plugin')) {
            add_action('admin_notices', array($this, 'tc_pro_admin_error_notice_tc7'));
        }
    }
    /*
    register admin notice if FREE version is also activated.
     */
    public function tc_pro_admin_error_notice_tc7()
    {
        $message = sprintf(esc_html__('%1$sFree Version%2$s of the %1$sCountry State City Dropdown CF7%2$s plugin is activated too. Please decativate to use PRO plugin.', 'tc_pro_csca'), '<strong>', '</strong>');
        printf('<div class="notice notice-error"><p>%1$s</p></div>', wp_kses_post($message));
    }
    /*
    set plugin constants
     */
    public function tc_pro_plugin_constants()
    {

        if (!defined('TC_PRO_CSCA_PATH')) {
            define('TC_PRO_CSCA_PATH', plugin_dir_path(__FILE__));
        }
        if (!defined('TC_PRO_CSCA_URL')) {
            define('TC_PRO_CSCA_URL', plugin_dir_url(__FILE__));
        }
        if (!defined('TC_PRO_CSCA_VERSION')) {
            define('TC_PRO_CSCA_VERSION', '5.7');
        }
    }

    public function load_custom_wp_admin_style()
    {
        $this->tc_pro_plugin_constants();
        wp_register_style('csca_admin_css', TC_PRO_CSCA_URL . 'includes/admin/css/style.css', false, TC_PRO_CSCA_VERSION);
		wp_enqueue_style('csca_admin_css');
        wp_enqueue_script('tc-csca-admin-script', TC_PRO_CSCA_URL . 'includes/admin/js/script.js');
        wp_localize_script('tc-csca-admin-script', 'tc_csca_admin_ajax', array('ajax_url' => admin_url('admin-ajax.php'), 'nonce' => wp_create_nonce('tc_caf_admin_ajax_nonce')));
    }
}
// Instantiate the plugin class.
$tc_pro_csca_plugin = new TC_PRO_CSCA_Plugin();
register_activation_hook(__FILE__, 'tc_pro_activate');

function tc_pro_activate()
{
    //update_option('tc_pro_auto_plugin','activated');
    //update_option('tc_pro_auto_plugin_version',TC_PRO_CSCA_VERSION);
}
register_deactivation_hook(__FILE__, 'tc_pro_deactivate');

function tc_pro_deactivate()
{
    update_option('tc_pro_auto_plugin', 'installed');
}
