<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}
    /**
     * ReduxFramework Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }


    // This is your option name where all the Redux data is stored.
    $opt_name = "csca_options";

    // This line is only for altering the demo. Can be easily removed.
    $opt_name = apply_filters( 'redux_demo/opt_name', $opt_name );

    /*
     *
     * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
     *
     */

    $sampleHTML = '';
    if ( file_exists( dirname( __FILE__ ) . '/info-html.html' ) ) {
        Redux_Functions::initWpFilesystem();

        global $wp_filesystem;

        $sampleHTML = $wp_filesystem->get_contents( dirname( __FILE__ ) . '/info-html.html' );
    }

    // Background Patterns Reader
    $sample_patterns_path = ReduxFramework::$_dir . '../sample/patterns/';
    $sample_patterns_url  = ReduxFramework::$_url . '../sample/patterns/';
    $sample_patterns      = array();
    
    if ( is_dir( $sample_patterns_path ) ) {

        if ( $sample_patterns_dir = opendir( $sample_patterns_path ) ) {
            $sample_patterns = array();

            while ( ( $sample_patterns_file = readdir( $sample_patterns_dir ) ) !== false ) {

                if ( stristr( $sample_patterns_file, '.png' ) !== false || stristr( $sample_patterns_file, '.jpg' ) !== false ) {
                    $name              = explode( '.', $sample_patterns_file );
                    $name              = str_replace( '.' . end( $name ), '', $sample_patterns_file );
                    $sample_patterns[] = array(
                        'alt' => $name,
                        'img' => $sample_patterns_url . $sample_patterns_file
                    );
                }
            }
        }
    }

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => 'Country State City Dropdown PRO',
        // Name that appears at the top of your panel
        //'display_version'      => '5.5',
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => __( 'Country Dropdown', 'tc_pro_csca' ),
        'page_title'           => __( 'Country State City Dropdown Settings', 'tc_pro_csca' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => false,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-menu',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => false,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => 'dashicons-menu',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => 'csca_settings',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => false,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'red',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    

   
    // Add content after the form.
//    $args['footer_text'] = __( '<p>This text is displayed below the options panel. It isn\'t required, but more info is always better! The footer_text field accepts all HTML.</p>', 'tc_pro_csca' );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */

    // -> START Basic Fields
   
$cnt=array();
$countries = get_countries();
foreach($countries as $key=>$country) {
	$cid=$country->id;
	$cname=$country->name;
	$cnt[$cid]=$cname;
}

$licenseKey = get_option( "CountryStateCityDropdownPROforContactForm7_lic_Key", "" );
        $liceEmail = get_option( "CountryStateCityDropdownPROforContactForm7_lic_email", "" );
        CountryStateCityDropdownPROforContactForm7Base::addOnDelete( function () {
            delete_option( "CountryStateCityDropdownPROforContactForm7_lic_Key" );
        } );
        if ( CountryStateCityDropdownPROforContactForm7Base::CheckWPPlugin( $licenseKey, $liceEmail, $this->licenseMessage, $this->responseObj, __FILE__ ) ) {
            
           $other_array=array(
           array(
                'id'        => 'csca_country_field_id',
			    'class'        => 'csca_country_field_class',
                'type'      => 'text',
                'title'     => __( 'Set ID Of Country Dropdown Field', 'tc_pro_csca' ),
                'subtitle'  => __( 'Please set ID or Class to your Country Dropdown Field. Function will append all countries in that specific dropdown. Please notice that field should be html dropdown.', 'tc_pro_csca' ),
                'desc'      => __( 'Enter ID with #prefix and Class with .prefix.', 'tc_pro_csca' ),
                'default'   => '',
			   	'class'     => 'csca_country_field_class',
                
            ),
             array(
                'id'        => 'csca_state_field_id',
                'type'      => 'text',
                'title'     => __( 'Set ID Of State Dropdown Field', 'tc_pro_csca' ),
                'subtitle'  => __( 'Please set ID or Class to your State Dropdown Field. Function will append all States in that specific dropdown. Please notice that field should be html dropdown.', 'tc_pro_csca' ),
                'desc'      => __( 'Enter ID with #prefix and Class with .prefix.', 'tc_pro_csca' ),
                'default'   => '',
                
            ),
             array(
                'id'        => 'csca_city_field_id',
                'type'      => 'text',
                'title'     => __( 'Set ID Of City Dropdown Field', 'tc_pro_csca' ),
                'subtitle'  => __( 'Please set ID or Class to your City Dropdown Field. Function will append all Cities in that specific dropdown. Please notice that field should be html dropdown.', 'tc_pro_csca' ),
                'desc'      => __( 'Enter ID with #prefix and Class with .prefix.', 'tc_pro_csca' ),
                'default'   => '',
                
            ),
            array(
                'id'       => 'csca_select_country_by_IP_others',
                'type'     => 'switch',
                'title'    => __( 'Set Default Country', 'tc_pro_csca' ),
                'subtitle' => __( "Select Default country when Page loads First Time.", 'tc_pro_csca' ),
                'on'=>'By IP',
	             'off'=>'Specific Country',
	             'default'  => true,
            ),
            array(
                'id'       => 'csca_default_country_others',
				'type'     => 'select',
                'title'    => __( 'Select Default Country', 'tc_pro_csca' ),
                'subtitle' => __( 'This country will be selected by default on page load.', 'tc_pro_csca' ),
               'options'  => $cnt,
				'required' => array( 'csca_select_country_by_IP_others', 'equals', false ),
            ),
            array(
                'id'       => 'csca_selected_countries_others',
                'type'     => 'select',
                'multi'    => true,
                'title'    => __( 'Display Specific Countries', 'tc_pro_csca' ),
                'subtitle' => __( 'Select Specific Countries to display in the Country Dropdown.', 'tc_pro_csca' ),
                //Must provide key => value pairs for radio options
                'options'  => $cnt,
                //'required' => array( 'opt-select', 'equals', array( '1', '3' ) ),
			 ),
			   
			 array(
                'id'        => 'csca_state_other_text_others',
                'type'      => 'text',
                'title'     => __( 'Other Field For State', 'tc_pro_csca' ),
                'subtitle'  => __( 'If State is not exists in the dropdown. Change value of Other field.', 'tc_pro_csca' ),
               // 'desc'      => __( 'Field Description', 'tc_pro_csca' ),
                'default'   => 'Other State',
                
            ),
			
			 array(
                'id'        => 'csca_city_other_text_others',
                'type'      => 'text',
                'title'     => __( 'Other Field For City', 'tc_pro_csca' ),
                'subtitle'  => __( 'If City is not exists in the dropdown. Change value of other field.', 'tc_pro_csca' ),
               // 'desc'      => __( 'Field Description', 'tc_pro_csca' ),

                'default'   => 'Other City',
                
            ),
			
			array(
                'id'        => 'csca_country_placeholder_text_others',
                'type'      => 'text',
                'title'     => __( 'Placeholder for Country Field', 'tc_pro_csca' ),
                'subtitle'  => __( 'You can change Select Country placeholder here.', 'tc_pro_csca' ),
               // 'desc'      => __( 'Field Description', 'tc_pro_csca' ),
                'default'   => 'Select Country',
                
            ),
			array(
                'id'        => 'csca_state_placeholder_text_others',
                'type'      => 'text',
                'title'     => __( 'Placeholder for State Field', 'tc_pro_csca' ),
                'subtitle'  => __( 'You can change Select State placeholder here.', 'tc_pro_csca' ),
               // 'desc'      => __( 'Field Description', 'tc_pro_csca' ),
                'default'   => 'Select State',
                
            ),
			array(
                'id'        => 'csca_city_placeholder_text_others',
                'type'      => 'text',
                'title'     => __( 'Placeholder for City Field', 'tc_pro_csca' ),
                'subtitle'  => __( 'You can change Select City placeholder here.', 'tc_pro_csca' ),
               // 'desc'      => __( 'Field Description', 'tc_pro_csca' ),
                'default'   => 'Select City',
            ),
           );

			
          $heading="Use These Settings for any form.";  
        }
        else {
            $other_array=array();
            $heading="<h1 style='line-height:36px'>Now you can use Country/State/City dropdown in any type of form. Please Activate your license to use this feature. Visit at <b><a href='https://trustyplugins.com' target='_blank' style=''>Trusty Plugins</a></b> to get license.</h1>";
        }
Redux::setSection( $opt_name, array(
        'title'      => __( 'General Settings', 'tc_pro_csca' ),
        'id'         => 'select-select23',
        'desc'       => '',
        //'subsection' => true,
        'fields'     =>$other_array,
        'heading'=>$heading,
 ) );
        
    


   
   
    
    /*
     * <--- END SECTIONS
     */


    /*
     *
     * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
     *
     */

    /*
    *
    * --> Action hook examples
    *
    */

    // If Redux is running as a plugin, this will remove the demo notice and links
    //add_action( 'redux/loaded', 'remove_demo' );

    // Function to test the compiler hook and demo CSS output.
    // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
    //add_filter('redux/options/' . $opt_name . '/compiler', 'compiler_action', 10, 3);

    // Change the arguments after they've been declared, but before the panel is created
    //add_filter('redux/options/' . $opt_name . '/args', 'change_arguments' );

    // Change the default value of a field after it's been set, but before it's been useds
    //add_filter('redux/options/' . $opt_name . '/defaults', 'change_defaults' );

    // Dynamically add a section. Can be also used to modify sections/fields
    //add_filter('redux/options/' . $opt_name . '/sections', 'dynamic_section');

    /**
     * This is a test function that will let you see when the compiler hook occurs.
     * It only runs if a field    set with compiler=>true is changed.
     * */
    if ( ! function_exists( 'compiler_action' ) ) {
        function compiler_action( $options, $css, $changed_values ) {
            echo '<h1>The compiler hook has run!</h1>';
            echo "<pre>";
            print_r( $changed_values ); // Values that have changed since the last save
            echo "</pre>";
            //print_r($options); //Option values
            //print_r($css); // Compiler selector CSS values  compiler => array( CSS SELECTORS )
        }
    }

    /**
     * Custom function for the callback validation referenced above
     * */
    if ( ! function_exists( 'redux_validate_callback_function' ) ) {
        function redux_validate_callback_function( $field, $value, $existing_value ) {
            $error   = false;
            $warning = false;

            //do your validation
            if ( $value == 1 ) {
                $error = true;
                $value = $existing_value;
            } elseif ( $value == 2 ) {
                $warning = true;
                $value   = $existing_value;
            }

            $return['value'] = $value;

            if ( $error == true ) {
                $field['msg']    = 'your custom error message';
                $return['error'] = $field;
            }

            if ( $warning == true ) {
                $field['msg']      = 'your custom warning message';
                $return['warning'] = $field;
            }

            return $return;
        }
    }

    /**
     * Custom function for the callback referenced above
     */
    if ( ! function_exists( 'redux_my_custom_field' ) ) {
        function redux_my_custom_field( $field, $value ) {
            print_r( $field );
            echo '<br/>';
            print_r( $value );
        }
    }

    /**
     * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
     * Simply include this function in the child themes functions.php file.
     * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
     * so you must use get_template_directory_uri() if you want to use any of the built in icons
     * */
    if ( ! function_exists( 'dynamic_section' ) ) {
        function dynamic_section( $sections ) {
            //$sections = array();
            $sections[] = array(
                'title'  => __( 'Section via hook', 'tc_pro_csca' ),
                'desc'   => __( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'tc_pro_csca' ),
                'icon'   => 'el el-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }
    }

    /**
     * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
     * */
    if ( ! function_exists( 'change_arguments' ) ) {
        function change_arguments( $args ) {
            //$args['dev_mode'] = true;

            return $args;
        }
    }

    /**
     * Filter hook for filtering the default value of any given field. Very useful in development mode.
     * */
    if ( ! function_exists( 'change_defaults' ) ) {
        function change_defaults( $defaults ) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }
    }

    /**
     * Removes the demo link and the notice of integrated demo from the redux-framework plugin
     */
    if ( ! function_exists( 'remove_demo' ) ) {
        function remove_demo() {
            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
                remove_filter( 'plugin_row_meta', array(
                    ReduxFrameworkPlugin::instance(),
                    'plugin_metalinks'
                ), null, 2 );

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
            }
        }
    }

